@@ -8,5 +8,9 @@ fn main() {
 
     let git_hash = String::from_utf8(output.stdout).unwrap();
 
-    println!("cargo:rustc-env=GIT_HASH={}", git_hash);
+    println!(
+        "cargo:rustc-env={}={}",
+        concat!("CARGO_", env!("CARGO_PKG_NAME"), "_GIT_HASH"),
+        git_hash
+    );
 }
